aboutsummaryrefslogtreecommitdiff
path: root/libctf/ctf-util.c
diff options
context:
space:
mode:
Diffstat (limited to 'libctf/ctf-util.c')
-rw-r--r--libctf/ctf-util.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/libctf/ctf-util.c b/libctf/ctf-util.c
index a0338f4..c29f460 100644
--- a/libctf/ctf-util.c
+++ b/libctf/ctf-util.c
@@ -162,7 +162,7 @@ ctf_str_append_noerr (char *s, const char *append)
/* A realloc() that fails noisily if called with any ctf_str_num_users. */
void *
-ctf_realloc (ctf_file_t *fp, void *ptr, size_t size)
+ctf_realloc (ctf_dict_t *fp, void *ptr, size_t size)
{
if (fp->ctf_str_num_refs > 0)
{
@@ -184,11 +184,11 @@ ctf_set_open_errno (int *errp, int error)
return NULL;
}
-/* Store the specified error code into the CTF container, and then return
- CTF_ERR / -1 for the benefit of the caller. */
+/* Store the specified error code into the CTF dict, and then return CTF_ERR /
+ -1 for the benefit of the caller. */
unsigned long
-ctf_set_errno (ctf_file_t * fp, int err)
+ctf_set_errno (ctf_dict_t *fp, int err)
{
fp->ctf_errno = err;
return CTF_ERR;